<template>
    <div class="app-container">
        <div class="filter-container">
            <el-button class="filter-item" type="primary" @click="openSafetyPersonForm('新增','')" >添加</el-button>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="safetyPersonQualificationData"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="姓名" prop="name" align="center">
                </el-table-column>
                <el-table-column label="职务" prop="post" align="center">
                </el-table-column>
                <el-table-column label="培训合格证号" prop="number" align="center">
                </el-table-column>
                <el-table-column label="培训合格证有效期" prop="validTime" align="center">
                    <template slot-scope="scope">
                        <span>{{ scope.row.validstarttime}}</span>
                        <span>-</span>
                        <span>{{ scope.row.validendtime}}</span>
                    </template>
                </el-table-column>
                <el-table-column label="图片">
                    <template slot-scope="scope">
                        <el-popover placement="top-start" trigger="click">
                            <!--                        <a href="http://192.168.0.7:8100/upload/enterprise/20210327184751998.png" target="_blank" title="查看最大化图片"><img src="http://192.168.0.7:8100/upload/enterprise/20210327184751998.png" style="width: 300px;height: 300px" /></a>-->
                            <!--                        <img slot="reference" src="http://192.168.0.7:8100/upload/enterprise/20210327184751998.png" style="width:40px;height:40px;margin-left:10px;cursor:pointer" ></img>-->
<!--                            <a  :href="scope.row.enterpriseResources.url" target="_blank" title="查看最大化图片"><img v-for="(item,index) in scope.row.enterpriseResources" :src="item.url" style="width: 300px;height: 300px" /></a>-->
                            <img slot="reference" v-for="(item,index) in scope.row.enterpriseResources" :src="item.url" :key="index" style="width:40px;height:40px;margin-left:10px;cursor:pointer" @click="showPic(item)"></img>
                        </el-popover>
                    </template>
                </el-table-column>
                <el-table-column label="操作" align="center" width="180" class-name="small-padding fixed-width">
                    <template slot-scope="scope">
                        <el-button type="text" @click="openSafetyPersonForm('修改',scope.row)">选择</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
        </div>
        <safetyPersonForm ref="safetyPersonForm" @getinfo="getSafetyPersonQualificationListData"></safetyPersonForm>
    </div>
</template>

<script>
import {uploadUrl} from '@/assets/upload/url'
import { computePageCount } from '@/utils'
import safetyPersonForm from "./components/safetyPersonForm";
import { getSafetyPersonQualification } from '@/api/safetyPersonQualification'
export default {
    name: "publicSecurityDepartment",
    props:["enterpriseId"],
    data(){
        return{
            tableKey:0,
            validTime:['',''],
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            searchContent:'',
            safetyPersonQualificationData:[],
        }
    },
    components:{
        safetyPersonForm
    },
    created(){
        this.getSafetyPersonQualificationListData()
    },
    methods:{
        async getSafetyPersonQualificationListData(){
            const params = {}
            params['pageIndex'] = this.currentPage
            params['pageSize'] = this.pageSize
            this.listLoading = true
            let res = await getSafetyPersonQualification(params,this.enterpriseId)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.safetyPersonQualificationData = res.data.result.records
                for(let i=0;i<this.safetyPersonQualificationData.length;i++){
                    if(this.safetyPersonQualificationData[i].enterpriseResources != null) {
                        for (let j = 0; j < this.safetyPersonQualificationData[i].enterpriseResources.length; j++) {
                            this.safetyPersonQualificationData[i].enterpriseResources[j].url = uploadUrl() + this.safetyPersonQualificationData[i].enterpriseResources[j].url
                        }
                    }
                }
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },
        showPic(val){
            window.open(val.url, '_blank')
        },
        openSafetyPersonForm(title,value){
            this.$refs.safetyPersonForm.showSafetyPersonForm(title,value,this.enterpriseId)
        },
        refreshHandle(){

        },
        queryHandle(){
            this.getSafetyPersonQualificationListData()
        },
        handleSizeChange(val) {
            this.listQuery.pageSize = val
            this.getSafetyPersonQualificationListData()
        },
        handleCurrentChange(val) {
            this.listQuery.pageIndex = val
            this.getSafetyPersonQualificationListData()
        },
    }
}
</script>

<style scoped>

</style>
